]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - client.h
Replace eof by error in receivers/filters/writers.
[paraslash.git] / client.h
index 06eeda387932765321c92093ee451aa590b25ae0..199d5c9a5b9564cdac6c8746ed8a82d873836657 100644 (file)
--- a/client.h
+++ b/client.h
@@ -73,8 +73,8 @@ struct private_client_data {
        char *inbuf;
        /** number of bytes loaded in \p inbuf */
        size_t *in_loaded;
        char *inbuf;
        /** number of bytes loaded in \p inbuf */
        size_t *in_loaded;
-       /** non-zero if input task encountered an eof or an errro condition */
-       int *in_eof;
+       /** Non-zero if input task encountered an eof or an error condition. */
+       int *in_error;
 };
 
 void client_close(struct private_client_data *pcd);
 };
 
 void client_close(struct private_client_data *pcd);